'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var React = require('react');
var Big = require('big.js');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var React__default = /*#__PURE__*/_interopDefaultLegacy(React);
var Big__default = /*#__PURE__*/_interopDefaultLegacy(Big);

var __defProp = Object.defineProperty;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
const COLOR_LIST = [
  "#FF7C7C",
  "#ADD4EF",
  "#BFDAA7",
  "#FCAC65",
  "#C6C1D2",
  "#7598E4",
  "#CF6D6C",
  "#4979CF",
  "#E1934B",
  "#829649",
  "#7D70AC",
  "#2559B7"
];
const echartsOptionsBase = {
  title: {
    show: true,
    text: "",
    top: 30,
    left: 24,
    textAlign: "left",
    textStyle: {
      color: "rgba(0,0,0,0.65)",
      fontSize: 16,
      lineHeight: 1
    }
  },
  grid: {
    x: 30,
    x2: 30,
    top: 90,
    bottom: 30,
    containLabel: true
  },
  toolbox: { show: false },
  tooltip: {
    show: true,
    trigger: "axis",
    backgroundColor: "rgba(255,255,255,0.9)",
    extraCssText: "box-shadow:  0px 0px 4px 0px rgba(0,0,0,0.25); border-radius: 2px; padding:10px 14px",
    formatter: function(data) {
      const _data = Array.isArray(data) ? data : [data];
      const _len = Big__default["default"](_data.length);
      const _count = _len.div(10).round(0, Big__default["default"].roundUp).toNumber();
      return `<div style="color: #c8c8c8;">${_data[0].name}</div><div style="column-count: ${_count};">${_data.map((d) => {
        switch (d.seriesType) {
          case "pie":
            return `<div>
                      <span style="display:inline-block;margin-right:5px;border-radius:10px;width:9px;height:9px;background-color:${d.color}"></span>
                      <span style="color: #595959;">${d.seriesName}:</span>
                      <span style="color: #262626;">${d.data.isShowPercentValue ? d.percent + "%" : d.data.value == null ? "--" : d.data.isPercent ? d.data.value + "%" : Big__default["default"](d.data.value).toFixed(d.data.decimalLength != null ? d.data.decimalLength : 2)}</span>
                  </div>`;
          case "line":
            return `<div>
                      <span style="display:inline-block;margin-right:5px;border-radius:10px;width:9px;height:9px;background-color:${d.color}"></span>
                      <span style="color: #595959;">${d.seriesName}:</span>
                      <span style="color: #262626;">${d.data.value == null ? "--" : d.data.isPercent ? d.data.value != null ? `${d.data.value}%` : `--` : Big__default["default"](d.data.value).toFixed(d.data.decimalLength != null ? d.data.decimalLength : 2)}</span>
                  </div>`;
          default:
            return `<div>
                      <span style="display:inline-block;margin-right:5px;border-radius:10px;width:9px;height:9px;background-color:${d.color}"></span>
                      <span style="color: #595959;">${d.seriesName}:</span>
                      <span style="color: #262626;">${d.data.value == null ? "--" : d.data.isPercent ? d.data.value + "%" : Big__default["default"](d.data.value).toFixed(d.data.decimalLength != null ? d.data.decimalLength : 2)}</span>
                  </div>`;
        }
      }).join("")}</div>`;
    }
  },
  xAxis: {
    type: "category",
    offset: 0,
    axisLine: {
      show: true,
      lineStyle: {
        color: "#D9D9D9"
      }
    },
    axisTick: {
      show: true,
      lineStyle: {}
    },
    splitLine: {
      show: false,
      lineStyle: {}
    },
    axisLabel: {
      rotate: 45,
      align: "right",
      textStyle: {
        color: "#8C8C8C"
      }
    },
    data: []
  },
  yAxis: [
    {
      show: true,
      type: "value",
      name: "",
      splitLine: {
        show: true,
        lineStyle: {
          color: "#E7EAEF",
          type: "dashed"
        }
      },
      axisLine: {
        show: false,
        lineStyle: {
          color: "#D9D9D9"
        }
      },
      axisLabel: {
        textStyle: {
          color: "#8C8C8C"
        }
      },
      axisTick: {
        show: false,
        lineStyle: {}
      }
    },
    {
      show: false,
      type: "value",
      name: "",
      splitLine: {
        show: false,
        lineStyle: {}
      },
      axisLine: {
        show: false,
        lineStyle: {
          color: "#D9D9D9"
        }
      },
      axisLabel: {
        textStyle: {
          color: "#8C8C8C"
        }
      },
      axisTick: {
        show: false,
        lineStyle: {}
      }
    }
  ],
  color: COLOR_LIST,
  textStyle: {},
  legend: {
    itemWidth: 10,
    itemHeight: 10,
    top: 30,
    left: 24,
    selectedMode: false,
    textStyle: {
      padding: [2, 0, 0, 0]
    },
    show: true,
    type: "scroll",
    position: "bottom",
    fontSize: 12,
    icon: "circle"
  },
  series: null
};
const mergeOption = (baseOptions, userOptions = {}) => {
  const _baseOptions = baseOptions || {};
  const _userOptions = userOptions || {};
  const _mergeOptions = __spreadValues(__spreadValues({}, _baseOptions), _userOptions);
  return _mergeOptions;
};
const truncate = (str, n) => {
  const r = /[^\x00-\xff]/g;
  let m;
  if (!str) {
    return "";
  }
  if (str.replace(r, "**").length > n) {
    m = Math.floor(n / 2);
    for (let i = m, l = str.length; i < l; i++) {
      if (str.slice(0, i).replace(r, "**").length >= n) {
        return str.slice(0, i) + "...";
      }
    }
  }
  return str;
};
function numberWithCommas(x) {
  if (!x) {
    return "--";
  }
  const parts = x.toString().split(".");
  parts[0] = parts[0].replace(/\B(?=(\d{3})+(?!\d))/g, ",");
  return parts.join(".");
}

const ChartContext = React__default["default"].createContext({});
const { Provider } = ChartContext;
const ChartProvider = (props) => {
  const { data, echartsOptions } = props;
  const { option: userOptions } = echartsOptions || {};
  return React__default["default"].createElement(Provider, { value: { data, echartsOptions, echartsOptionsBase, userOptions } }, props.children);
};

const buildChartOption = (chartOptions, settings, chartType) => {
  var _a;
  const _option = chartOptions || {};
  const { legendPosition = "top" } = settings || {};
  if (legendPosition) {
    switch (legendPosition) {
      case "top":
        _option.legend.top = 60;
        _option.legend.bottom = "auto";
        _option.legend.left = "center";
        _option.legend.padding = [5, 5];
        _option.grid.top = 110;
        _option.grid.left = chartType == "scatter" ? 70 : 20;
        _option.grid.right = chartType == "scatter" ? 100 : chartType == "bar-horizontal" ? 50 : 20;
        _option.grid.bottom = chartType == "scatter" ? 100 : 45;
        _option.legend.orient = "horizontal";
        break;
      case "bottom":
        _option.legend.top = "auto";
        _option.legend.bottom = chartType == "scatter" ? 40 : 20;
        _option.legend.left = "center";
        _option.legend.padding = [5, 5];
        _option.grid.top = 70;
        _option.grid.left = chartType == "scatter" ? 70 : 20;
        _option.grid.right = chartType == "scatter" ? 50 : chartType == "bar-horizontal" ? 50 : 20;
        _option.grid.bottom = chartType == "scatter" ? 100 : 45;
        _option.legend.orient = "horizontal";
        break;
      case "left":
        _option.legend.top = 60;
        _option.legend.bottom = 60;
        _option.legend.left = 20;
        _option.legend.right = "auto";
        _option.legend.padding = [5, 5];
        _option.grid.top = 70;
        _option.grid.left = 150;
        _option.grid.right = chartType == "scatter" ? 50 : 20;
        _option.grid.bottom = chartType == "scatter" ? 100 : 20;
        _option.legend.orient = "vertical";
        break;
      case "right":
        _option.legend.top = 60;
        _option.legend.bottom = 60;
        _option.legend.left = "auto";
        _option.legend.right = chartType == "scatter" ? 50 : 20;
        _option.legend.padding = [5, 5];
        _option.grid.top = 70;
        _option.grid.left = chartType == "scatter" ? 70 : 20;
        _option.grid.right = chartType == "scatter" ? 170 : 200;
        _option.grid.bottom = chartType == "scatter" ? 100 : 20;
        _option.legend.orient = "vertical";
        break;
      default:
        _option.legend.top = "auto";
        _option.legend.bottom = "6%";
        _option.legend.left = "center";
        _option.grid.top = "18%";
        _option.grid.left = "8%";
        _option.grid.right = "8%";
        _option.grid.bottom = "15%";
        break;
    }
    if (_option.legend.show == false) {
      _option.legend.top = 60;
      _option.legend.bottom = "auto";
      _option.legend.left = "center";
      _option.legend.padding = [5, 5];
      _option.grid.top = 100;
      _option.grid.left = 20;
      _option.grid.right = chartType == "scatter" ? 50 : 20;
      _option.grid.bottom = chartType == "scatter" ? 60 : 20;
    }
  } else {
    _option.legend.top = "auto";
    _option.legend.bottom = "6%";
    _option.legend.left = "center";
    _option.grid.top = "18%";
    _option.grid.left = "8%";
    _option.grid.right = "8%";
    _option.grid.bottom = "15%";
    _option.legend.orient = "horizontal";
  }
  const iconLineWithRing = "path://M14,4h-2.1C11.4,1.7,9.4,0,7,0S2.6,1.7,2.1,4H0v2h2.1c0.5,2.3,2.5,4,4.9,4s4.4-1.7,4.9-4H14V4z M7,8  C5.3,8,4,6.7,4,5s1.3-3,3-3s3,1.3,3,3S8.7,8,7,8z";
  if (chartType == "pie") {
    _option.legend.data = _option.series[0] && _option.series[0].data.map((item) => {
      const textStyle = {
        padding: [2, 0, 0, 0]
      };
      return {
        name: item.name,
        icon: "circle",
        textStyle
      };
    });
  } else {
    const _legendData = (_a = _option.series) == null ? void 0 : _a.map((item) => {
      let icon = "circle";
      const textStyle = {
        padding: [2, 0, 0, 0]
      };
      switch (item.type) {
        case "bar":
          icon = "circle";
          break;
        case "line":
          icon = iconLineWithRing;
          break;
      }
      return {
        name: `${item.name}`,
        icon,
        textStyle
      };
    });
    if (_option.legend.show && legendPosition && ["left", "right"].includes(legendPosition) && (chartType == "stack" || chartType == "line-stack")) {
      _option.legend.data = _legendData.reverse();
      _option.tooltip.formatter = function(data) {
        return `<div>${data[0].name}</div>${data.reverse().map((d) => {
          switch (d.seriesType) {
            case "pie":
              return `<div>
                        <span style="display:inline-block;margin-right:5px;border-radius:10px;width:9px;height:9px;background-color:${d.color}"></span>
                        <span>${d.data.label ? d.data.label.formatter(d, true) : d.data.value}</span>
                    </div>`;
            default:
              return `<div>
                        <span style="display:inline-block;margin-right:5px;border-radius:10px;width:9px;height:9px;background-color:${d.color}"></span>
                        <span>${d.seriesName}:</span>
                        <span>${d.data.label ? d.data.label.formatter(d, true) : d.data.value}</span>
                    </div>`;
          }
        }).join("")}`;
      };
    } else {
      _option.legend.data = _legendData;
    }
  }
  _option.legend.formatter = (text) => {
    if (isNaN(text)) {
      return truncate(text, 12);
    } else {
      return text;
    }
  };
  _option.tooltip.trigger = ["pie", "scatter"].includes(chartType) ? "item" : "axis";
  return _option;
};

var index = {
  ChartProvider,
  ChartContext,
  mergeOption,
  buildChartOption,
  numberWithCommas,
  COLOR_LIST,
  truncate
};

exports.COLOR_LIST = COLOR_LIST;
exports.ChartContext = ChartContext;
exports.ChartProvider = ChartProvider;
exports.buildChartOption = buildChartOption;
exports["default"] = index;
exports.mergeOption = mergeOption;
exports.numberWithCommas = numberWithCommas;
exports.truncate = truncate;
